import numpy as np
import random


def generateObjects(count, center=0, width=10, massmult=100):
    """Generate a `count` x 3 matrix of (x, y) coordinates corresponding
    to `count` number of arbitrarly placed elements

    Args:
        count (int): the number of (x, y) pairs to generate
        center (float): the center of our distribution
        width (float): the width of our distribution
        massmult (float): mass multiplier

    Returns:
        a (`count`, 3) list/array of positions

        The return value should look like:
            [[x1, y1, mass1],
             [x2, y2, mass2],
             ...
            ]
    """
    # Numpy
    # positions = width * np.random.random((count, 2)) - ((width / 2) - center)
    # weights = np.random.random((count, 1)) * massmult
    # data = np.concatenate((positions, weights), axis=1)
    # return data.tolist()

    # Lists
    data = []
    for _ in range(count):
        data.append(
            [
                width * random.random() - ((width / 2) - center),
                width * random.random() - ((width / 2) - center),
                random.random() * massmult,
            ]
        )
    return data


def generateObjectsNormal(count, center=0, width=10, massmult=100):
    return np.random.multivariate_normal(
        [center, center, massmult],
        [[width / 2, 0, 0], [0, width / 2, 0], [0, 0, massmult * 10]],
        count,
    ).tolist()
